FLAAT
=====

Python support for OIDC Access Tokens -- FLAAT.
Use decorators for authorising access to OIDC authenticated REST APIs.

Documentation
-------------

If you want to protect a REST interface, that is used with OpenID Connect
(OIDC), this documentation is what you are looking for.

Flaat supports to limit access to any REST endpoint you have. We do
support this by making use of decorators.  Three different decorators are
currently supported:

.. toctree::
   :maxdepth: 1

   flaat/installation
   flaat/examples/aio
   flaat/examples/flask
   flaat/flaat-userinfo
   flaat/development


Reporting Bugs
--------------

Issues are managed at `github <https://github.com/indigo-dc/flaat/issues/>`_.


Why this name?
--------------
Previously FLAAT only supported Flask, hence the name FLAsk support for Access Tokens (FLAAT).


API reference
-------------

If you are looking for information on a specific function, class or
method, this part of the documentation is for you.

.. toctree::
   :maxdepth: 2

   flaat/api/index
   flaat/api/config

-----------------


Indices
=======

* :ref:`genindex`
* :ref:`modindex`
